@@ -8,6 +8,14 @@ from jinja2 import Template
 from ruamel import yaml
 
 
+class PydanticSchemageException(Exception):
+    pass
+
+
+class GeneratedCodeExecutionFailed(PydanticSchemageException):
+    pass
+
+
 def yaml_to_box(filename: Union[Path, str]):
     filename = Path(filename)
     if not filename.is_file() and filename.parent != Path(__file__).parent:
@@ -18,9 +26,11 @@ def yaml_to_box(filename: Union[Path, str]):
 @attr.s
 class SchemaGen:
     filename: Union[Path, str] = attr.ib()
+    _additional_imports = set()
 
     _templates: Box = yaml_to_box("templates.yml")
     _module: Template = Template(_templates.module)
+    _schemas: Template = Template(_templates.schemas)
     _schema: Template = Template(_templates.schema)
     _prop: Template = Template(_templates.prop)
     _config: Template = Template(_templates.config)
@@ -30,10 +40,15 @@ class SchemaGen:
         if not self.filename.is_file():
             raise FileNotFoundError(f"{self.filename.name}")
         self.file = yaml_to_box(self.filename)
-        self.code = self._make_module()
+        self.code = self._make_module_and_schemas()
 
-    def _make_module(self) -> str:
-        return self._module.render(schemas=self._make_schemas())
+    def _make_module_and_schemas(self) -> str:
+        schemas = self._schemas.render(schemas=self._make_schemas())
+        additional_imports = (
+            "\n".join(self._additional_imports) if self._additional_imports else ""
+        )
+        module = self._module.render(imports=additional_imports)
+        return "\n\n\n".join([module, schemas])
 
     def _make_schemas(self) -> str:
         schemas = []
@@ -53,9 +68,15 @@ class SchemaGen:
     def _make_prop(self, prop: Box) -> str:
         if not prop.get("default"):
             default_value = ""
+        elif prop.type in ["str", "date", "datetime", "time"]:
+            default_value = f' = "{prop.default}"'
         else:
             default_value = f" = {prop.default}"
 
+        if prop.type in ["date", "datetime", "time"]:
+            self._additional_imports.add("import datetime as dt")
+            prop.type = f"dt.{prop.type}"
+
         if prop.get("optional"):
             prop_type = f"Optional[{prop.type}]"
         else:
